@@ -3,13 +3,10 @@ typedef struct mthread {
 	perl_mutex lock;
 	message_queue queue;
 	UV id;
-#ifdef WIN32
-	DWORD  thr;                 /* OS's idea if thread id */
-	HANDLE handle;              /* OS's waitable handle */
-#else
-	pthread_t thr;              /* OS's handle for the thread */
+#ifndef WIN32
 	sigset_t initial_sigmask;   /* Thread wakes up with signals blocked */
 #endif
+	AV* cache;
 	struct {
 		IV* list;
 		UV head;
@@ -19,7 +16,6 @@ typedef struct mthread {
 
 extern void S_create_push_threads(PerlInterpreter*, HV* options, SV* startup);
 #define create_push_threads(options, startup) S_create_push_threads(aTHX, options, startup)
-extern mthread* clone_thread(pTHX_ IV stack_size);
 void store_self(pTHX, mthread*);
 mthread* S_get_self(pTHX);
 #define get_self() S_get_self(aTHX)
